@@ -2,8 +2,9 @@ package Plagger::Entry;
 use strict;
 
 use base qw( Class::Accessor::Fast );
-__PACKAGE__->mk_accessors(qw( title author tags date link id summary body rate  meta));
+__PACKAGE__->mk_accessors(qw( title author tags date link id summary body rate  icon meta));
 
+use Digest::MD5;
 use DateTime::Format::Mail;
 use Storable;
 
@@ -63,5 +64,11 @@ sub clone {
     $clone;
 }
 
+sub id_safe {
+    my $self = shift;
+    my $id   = $self->id || $self->link;
+    $id =~ m!^https?://! ? Digest::MD5::md5_hex($id) : $id;
+}
+
 1;
 
