@@ -12,6 +12,7 @@ sub register {
         $self,
         'smartfeed.init'  => \&feed_init,
         'smartfeed.entry' => \&feed_entry,
+        'smartfeed.finalize' => \&feed_finalize,
     );
 }
 
@@ -23,8 +24,6 @@ sub feed_init {
     $feed->id( $self->conf->{id} || ('smartfeed:' . $self->rule->id) );
     $feed->title( $self->conf->{title} || "Entries " . $self->rule->as_title );
 
-    $context->update->add($feed);
-
     $self->{feed} = $feed;
 }
 
@@ -33,4 +32,9 @@ sub feed_entry {
     $self->{feed}->add_entry($args->{entry}->clone);
 }
 
+sub feed_finalize {
+    my($self, $context, $args) = @_;
+    $context->update->add($self->{feed}) if $self->{feed}->count;
+}
+
 1;
